===============================================================
``psyclone.domain.lfric.transformations.lfric_loop_fuse_trans``
===============================================================

.. automodule:: psyclone.domain.lfric.transformations.lfric_loop_fuse_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.transformations.lfric_loop_fuse_trans


Classes
=======

- :py:class:`LFRicLoopFuseTrans`:
  Dynamo0.3 API specialisation of the


.. autoclass:: LFRicLoopFuseTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicLoopFuseTrans
      :parts: 1
